@echo off

:: MSI Generation Tool for Office 365 sources 
:: version 1.2
::
:: release history
:: 1.0: initial version
:: 1.1: added check of Office variant (x32 or x64)
::      updated the project wxs file:
::      - take into account variant in package name
::      - modified cab generation parameter for handling sources above 2 GB
:: 1.2: correction in wxs file for target directory
::      added execution time information

:: Parameters

:: log file
set OUTPUT_LOG=MSI_Generation.log

:: Office version, will be retrieved lated in the script
set OFFFICE_VERSION=Unknown

:: configuration file for downloading the sources
set OFFICE_DOWNLOAD_CONFIGURATION_FILE=O365ProPlusRetail_DownloadSources.xml

:: Office platform: 32 -> 32 bits, 64 -> 64 bits
:: will be retrieved lated in the script
set OFFICE_PLATFORM=32

:: Office Release and Channel
set OFFICE_RELEASE=1808
set OFFICE_CHANNEL=SA

:: Main WXS project name
set WXS_PROJECT=O365_Sources

:: if you didn't install the WiX toolset using the provided setup, set this variable to refer to the location of the BIN folder
::set WIX=C:\Tools\wix311-binaries\

cd %~dp0

:: delete intermediate files generated for the MSI creation

if exist OfficeSourceFiles.wxs del OfficeSourceFiles.wxs >nul
if exist *.wixobj del *.wixobj >nul
if exist *.wixpdb del *.wixpdb >nul
if exist *.msi del *.msi >nul
if exist *.cab del *.cab >nul

::goto MSIGeneration

:: delete any previous sources

if exist Office (
	del /f /s /q Office >nul
	rd /s /q Office >nul
)

:: download the sources

@echo Downloading sources...
@echo %time%

Setup.exe /download %OFFICE_DOWNLOAD_CONFIGURATION_FILE%

@echo ... done
@echo %time%

if ErrorLevel == 0 goto MSIGeneration

msg * /w "Error while downloading the files, try again later..."

goto End
 
:MSIGeneration

@echo Starting MSI generation
@echo %time%

:: retrieve the version number
:: in the downloaded sources folder there is a sub-folder in Office/Data with the version number

for /F %%I in ('dir Office\Data /a:d /b') do set OFFICE_VERSION=%%I

:: retrieve the Office variant

if exist Office\Data\v32.cab set OFFICE_PLATFORM=32
if exist Office\Data\v64.cab set OFFICE_PLATFORM=64
 
:: generate the list of files to include in the MSI
:: ------------------------------------------------

:: options for Heat.exe
:: -out = output file
:: dir  = folder to take into account
:: -gg  = automatically generate GUID for components when creating the files list 
:: -cg  = name of the components group in the project WXS file
:: -dr  = name of the directory where are added the components in the directory structure defined in the WXS project
:: -var = replace the name of the source directory by a variable
::        SourceDir -> var.SourcesDir
:: -v   = verbose mode

@echo Generating list of files...

"%WIX%\heat.exe" dir ".\Office" -gg -cg OfficeSources -dr INSTALLDIR -var var.OfficeSourcesDir -out OfficeSourceFiles.wxs -v > %OUTPUT_LOG%

@echo ... done
@echo %time%

:: file list compilation
:: ---------------------

:: options for Candle.exe
:: -out  = output file
:: -d    = set the value for the variables defined in the WXS file 
::         var.SourcesDir -> full path for accessing the files

@echo Compiling list of files...

"%WIX%\candle.exe" OfficeSourceFiles.wxs -arch x64 -dOfficeSourcesDir="%~dp0\Office" -out .\ >> %OUTPUT_LOG%

@echo ... done
@echo %time%

:: main project file compilation
:: -----------------------------

:: options for Candle.exe
:: -out  = output file
:: -d    = set the value for the variables defined in the WXS file 
::         var.OFFICE_VERSION -> version number 
::         var.OFFICE_PLATFORM -> 32 or 64 bits platform
::         var.Office_RELEASE -> release number (format: YYMM)
::         var.OFFICE_CHANNEL -> update channel (SA, SAT, M)

@echo Compiling project...

"%WIX%\candle.exe" %WXS_PROJECT%.wxs -arch x64 -ext WixUIExtension -dOFFICE_VERSION=%OFFICE_VERSION% -dOFFICE_PLATFORM=%OFFICE_PLATFORM% -dOFFICE_RELEASE=%OFFICE_RELEASE% -dOFFICE_CHANNEL=%OFFICE_CHANNEL% -out .\ >> %OUTPUT_LOG%

@echo ... done
@echo %time%

:: MSI file creation
:: -----------------

:: options for Light.exe
:: -b   = base path for looking for files
:: -out = name if the MSI file to generate

@echo Creating MSI file...

"%WIX%\light.exe" %WXS_PROJECT%.wixobj -b .\ OfficeSourceFiles.wixobj -out O365PP_%OFFICE_RELEASE%-%OFFICE_CHANNEL%_Sources_%OFFICE_VERSION%_x%OFFICE_PLATFORM%.MSI -ext WixUIExtension >> %OUTPUT_LOG%

@echo ... done
@echo %time%

:End

pause
 